Command line options
====================

Basic commands
--------------

.. toctree::
    :maxdepth: 1

    nbgrader
    nbgrader-extension

Instructor commands
-------------------

.. toctree::
    :maxdepth: 1

    nbgrader-quickstart
    nbgrader-assign
    nbgrader-validate
    nbgrader-autograde
    nbgrader-formgrade
    nbgrader-feedback

The following commands are meant for instructors, but are only relevant when using nbgrader in a shared server environment:

.. toctree::
    :maxdepth: 1

    nbgrader-release
    nbgrader-list
    nbgrader-collect

Student commands
----------------

Note that these commands are meant for students, but are only relevant when using nbgrader in a shared server environment.

.. toctree::
    :maxdepth: 1

    nbgrader-list
    nbgrader-fetch
    nbgrader-validate
    nbgrader-submit
